@@ -1,18 +1,18 @@
 #! /usr/bin/env python3
 
 import time
-from typing import Dict, List
 
 import click
 
+import spyctl.cli as cli
+import spyctl.commands.create as c
+import spyctl.commands.diff as d
+import spyctl.commands.get as g
+import spyctl.commands.merge as m
+import spyctl.commands.validate as v
 import spyctl.config.configs as cfgs
 import spyctl.config.secrets as s
 import spyctl.spyctl_lib as lib
-import spyctl.commands.get as g
-import spyctl.commands.create as c
-import spyctl.commands.merge as m
-import spyctl.commands.diff as d
-import spyctl.cli as cli
 from spyctl.commands.apply import handle_apply
 from spyctl.commands.delete import handle_delete
 
@@ -710,5 +710,31 @@ def merge(filename, output, with_file=None, latest=False):
     m.handle_merge(filename, with_file, latest, output)
 
 
+# ----------------------------------------------------------------- #
+#                       Validate Subcommand                         #
+# ----------------------------------------------------------------- #
+
+
+@main.command("validate", cls=lib.CustomCommand, epilog=SUB_EPILOG)
+@click.help_option("-h", "--help", hidden=True)
+@click.option(
+    "-f",
+    "--filename",
+    "file",
+    help="Target file to validate",
+    metavar="",
+    required=True,
+    type=click.File(),
+)
+def validate(file):
+    """Validate spyderbat resource and spyctl configuration files.
+
+    \b
+    example:
+      spyctl validate -f my_baseline.yaml
+    """
+    v.handle_validate(file)
+
+
 if __name__ == "__main__":
     main()
